#include <unistd.h>

#define REAL_PATH "/usr/share/backuppc/lib/realindex.cgi"

int main (int argc, char *argv[]) {
    execv(REAL_PATH, argv);
    return 0;
}

